TransactionConditional

Struct TransactionConditional 

pub struct TransactionConditional {
    pub known_accounts: HashMap<Address, AccountStorage, FbBuildHasher<20>>,
    pub block_number_min: Option<u64>,
    pub block_number_max: Option<u64>,
    pub timestamp_min: Option<u64>,
    pub timestamp_max: Option<u64>,
}
Available on crate feature eth only.
Options for conditional raw transaction submissions.

TransactionConditional represents the preconditions that determine the inclusion of the transaction, enforced out-of-protocol by the sequencer.

See also https://github.com/ethereum-optimism/op-geth/blob/928070c7fc097362ed2d40a4f72889ba91544931/core/types/transaction_conditional.go#L74-L76.

Fields

known_accounts: HashMap<Address, AccountStorage, FbBuildHasher<20>>

A map of account addresses to their expected storage states. Each account can have a specified storage root or explicit slot-value pairs.

block_number_min: Option<u64>

The minimal block number at which the transaction can be included. None indicates no minimum block number constraint.

block_number_max: Option<u64>

The maximal block number at which the transaction can be included. None indicates no maximum block number constraint.

timestamp_min: Option<u64>

The minimal timestamp at which the transaction can be included. None indicates no minimum timestamp constraint.

timestamp_max: Option<u64>

The maximal timestamp at which the transaction can be included. None indicates no maximum timestamp constraint.

Implementations

Source

impl TransactionConditional

pub const fn has_exceeded_block_attributes( &self, block: &BlockConditionalAttributes, ) -> bool

Returns true if any configured block parameter (timestamp_max, block_number_max) are exceeded by the given block parameter.

E.g. the block parameter’s timestamp is higher than the configured block_number_max

pub const fn has_exceeded_block_number(&self, block_number: u64) -> bool

Returns true if the configured max block number is lower or equal to the given block_number

pub const fn has_exceeded_timestamp(&self, timestamp: u64) -> bool

Returns true if the configured max timestamp is lower or equal to the given timestamp

pub const fn matches_block_attributes( &self, block: &BlockConditionalAttributes, ) -> bool

Returns true if the transaction matches the given block attributes.

pub const fn matches_block_number(&self, block_number: u64) -> bool

Returns true if the transaction matches the given block number.

pub const fn matches_timestamp(&self, timestamp: u64) -> bool

Returns true if the transaction matches the given timestamp.

pub fn cost(&self) -> u64

Computes the aggregate cost of the preconditions; total number of storage lookups required