SimBlock

Struct SimBlock 

pub struct SimBlock<TxReq = TransactionRequest> {
    pub block_overrides: Option<BlockOverrides>,
    pub state_overrides: Option<HashMap<Address, AccountOverride, FbBuildHasher<20>>>,
    pub calls: Vec<TxReq>,
}
Available on crate feature eth only.
Represents a batch of calls to be simulated sequentially within a block. This struct includes block and state overrides as well as the transaction requests to be executed.

Fields

block_overrides: Option<BlockOverrides>

Modifications to the default block characteristics.

state_overrides: Option<HashMap<Address, AccountOverride, FbBuildHasher<20>>>

State modifications to apply before executing the transactions.

calls: Vec<TxReq>

A vector of transactions to be simulated.

Implementations

Source

impl<TxReq> SimBlock<TxReq>

pub fn with_state_overrides( self, overrides: HashMap<Address, AccountOverride, FbBuildHasher<20>>, ) -> SimBlock<TxReq>

Enables state overrides

pub fn with_block_overrides(self, overrides: BlockOverrides) -> SimBlock<TxReq>

Enables block overrides

pub fn call(self, call: TxReq) -> SimBlock<TxReq>

Adds a call to the block.

pub fn extend_calls( self, calls: impl IntoIterator<Item = TxReq>, ) -> SimBlock<TxReq>

Adds multiple calls to the block.

pub fn block_number_override(&self) -> Option<Uint<256, 4>>

Returns the block’s block number override if it exists.