SimCallResult

Struct SimCallResult 

pub struct SimCallResult {
    pub return_data: Bytes,
    pub logs: Vec<Log>,
    pub gas_used: u64,
    pub status: bool,
    pub error: Option<SimulateError>,
}
Available on crate feature eth only.
Captures the outcome of a transaction simulation. It includes the return value, logs produced, gas used, and the status of the transaction.

Fields

return_data: Bytes

The raw bytes returned by the transaction.

logs: Vec<Log>

Logs generated during the execution of the transaction.

gas_used: u64

The amount of gas used by the transaction.

status: bool

The final status of the transaction, typically indicating success or failure.

error: Option<SimulateError>

Error in case the call failed