pub struct SimulatePayload<TxReq = TransactionRequest> {
pub block_state_calls: Vec<SimBlock<TxReq>>,
pub trace_transfers: bool,
pub validation: bool,
pub return_full_transactions: bool,
}eth only.Expand description
Simulation options for executing multiple blocks and transactions.
This struct configures how simulations are executed, including whether to trace token transfers, validate transaction sequences, and whether to return full transaction objects.
Fields
block_state_calls: Vec<SimBlock<TxReq>>Array of block state calls to be executed at specific, optional block/state.
trace_transfers: boolFlag to determine whether to trace ERC20/ERC721 token transfers within transactions.
validation: boolFlag to enable or disable validation of the transaction sequence in the blocks.
return_full_transactions: boolFlag to decide if full transactions should be returned instead of just their hashes.
Implementations
Sourceimpl<TxReq> SimulatePayload<TxReq>
impl<TxReq> SimulatePayload<TxReq>
Sourcepub fn extend(self, block: SimBlock<TxReq>) -> SimulatePayload<TxReq>
pub fn extend(self, block: SimBlock<TxReq>) -> SimulatePayload<TxReq>
Adds a block to the simulation payload.
Sourcepub fn extend_blocks(
self,
blocks: impl IntoIterator<Item = SimBlock<TxReq>>,
) -> SimulatePayload<TxReq>
pub fn extend_blocks( self, blocks: impl IntoIterator<Item = SimBlock<TxReq>>, ) -> SimulatePayload<TxReq>
Adds multiple blocks to the simulation payload.
Sourcepub const fn with_trace_transfers(self) -> SimulatePayload<TxReq>
pub const fn with_trace_transfers(self) -> SimulatePayload<TxReq>
Enables tracing of token transfers.
Sourcepub const fn with_validation(self) -> SimulatePayload<TxReq>
pub const fn with_validation(self) -> SimulatePayload<TxReq>
Enables validation of the transaction sequence.
Sourcepub const fn with_full_transactions(self) -> SimulatePayload<TxReq>
pub const fn with_full_transactions(self) -> SimulatePayload<TxReq>
Enables returning full transactions.