pub struct StorageValuesRequest(pub HashMap<Address, Vec<FixedBytes<32>>, FbBuildHasher<20>>);Available on crate feature
eth only.Expand description
Request type for eth_getStorageValues.
Maps contract addresses to the storage slot keys to read.
See also https://github.com/ethereum/execution-apis/issues/752.
Tuple Fields
0: HashMap<Address, Vec<FixedBytes<32>>, FbBuildHasher<20>>Implementations
Sourceimpl StorageValuesRequest
impl StorageValuesRequest
Sourcepub fn new() -> StorageValuesRequest
pub fn new() -> StorageValuesRequest
Creates an empty request.
Sourcepub fn with_keys(
self,
address: Address,
keys: Vec<FixedBytes<32>>,
) -> StorageValuesRequest
pub fn with_keys( self, address: Address, keys: Vec<FixedBytes<32>>, ) -> StorageValuesRequest
Adds storage keys to read for an address, replacing any existing keys.
use alloy_primitives::{address, b256};
use alloy_rpc_types_eth::StorageValuesRequest;
let usdt = address!("0xdAC17F958D2ee523a2206206994597C13D831ec7");
let req = StorageValuesRequest::new().with_keys(
usdt,
vec![
b256!("0x0000000000000000000000000000000000000000000000000000000000000002"),
b256!("0x0000000000000000000000000000000000000000000000000000000000000006"),
],
);
assert_eq!(req.total_slots(), 2);Sourcepub fn with_key(
self,
address: Address,
key: FixedBytes<32>,
) -> StorageValuesRequest
pub fn with_key( self, address: Address, key: FixedBytes<32>, ) -> StorageValuesRequest
Appends a single storage key for an address.
If the address already has keys, the new key is appended.
Sourcepub fn total_slots(&self) -> usize
pub fn total_slots(&self) -> usize
Returns the total number of storage slots requested across all addresses.
Sourcepub fn into_inner(
self,
) -> HashMap<Address, Vec<FixedBytes<32>>, FbBuildHasher<20>>
pub fn into_inner( self, ) -> HashMap<Address, Vec<FixedBytes<32>>, FbBuildHasher<20>>
Consumes the wrapper, returning the inner map.